AnimatedCheckmark class

An animated checkmark widget that draws a circle and a checkmark inside it with customizable duration, size, strokeWidth, and callback on complete.

Inheritance

Constructors

AnimatedCheckmark({Key? key, double size = 60.0, Color color = const Color(0xFF22C55E), double strokeWidth = 4.0, Duration duration = const Duration(milliseconds: 600), VoidCallback? onCompleted})
Creates an AnimatedCheckmark widget.
const

Properties

color → Color
The color of the checkmark drawing and its outer circle.
final
duration → Duration
The duration of the entire checkmark animation.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCompleted → VoidCallback?
Optional callback triggered when the drawing animation completes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
The size (width and height) of the checkmark widget.
final
strokeWidth → double
The stroke width of the drawing lines.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AnimatedCheckmark>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited