OtpSuccessAnimationStyle enum

Animation style applied when transitions to the success checkmark state.

Inheritance
Available extensions

Values

bounce → const OtpSuccessAnimationStyle

The success checkmark container bounces in.

scale → const OtpSuccessAnimationStyle

The success checkmark container scales up and fades in.

fade → const OtpSuccessAnimationStyle

The success checkmark container fades in.

none → const OtpSuccessAnimationStyle

No animation is applied to the success checkmark transition.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OtpSuccessAnimationStyle>
A constant List of the values in this enum, in order of their declaration.