LiquidWaterBox class
A premium, individual OTP slot box designed as a glass container filled with animated wavy liquid, floating bubbles, and subtle light reflections.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LiquidWaterBox
Constructors
- LiquidWaterBox({Key? key, required String char, required bool isFocused, required bool isSuccess, required bool isError, required bool isVerifying, required double boxHeight, required double boxWidth, required BorderRadius borderRadius, required Color activeBorderColor, required Color inactiveBorderColor, required Color successColor, required Color errorColor, Color boxBackgroundColor = const Color(0xFF1E293B), TextStyle? textStyle})
-
Creates a LiquidWaterBox widget.
const
Properties
- activeBorderColor → Color
-
The active highlight border color.
final
- borderRadius → BorderRadius
-
Border radius of the box.
final
- boxBackgroundColor → Color
-
The background fill color of the empty glass container.
final
- boxHeight → double
-
Height of the box.
final
- boxWidth → double
-
Width of the box.
final
- char → String
-
The character value of this digit (empty if not entered).
final
- errorColor → Color
-
The error accent color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveBorderColor → Color
-
The inactive border color.
final
- isError → bool
-
Whether the verification failed.
final
- isFocused → bool
-
Whether this box currently has input focus.
final
- isSuccess → bool
-
Whether the verification succeeded.
final
- isVerifying → bool
-
Whether the verification is in progress.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successColor → Color
-
The success accent color.
final
- textStyle → TextStyle?
-
Text style for the digit.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LiquidWaterBox> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited