NexusLink class
One edge of the lattice, drawn from from to to as progress runs to 1.
Properties
-
from
→ Offset
-
Start point of the edge, in the coordinate space of the painter.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
progress
→ double
-
How much of the edge has been drawn, between
0 and 1.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
to
→ Offset
-
End point of the edge.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited